@@ -37,6 +37,11 @@ final class ParsingFileAnalyserTest extends TestCase
                 25,
                 30,
                 33,
+                38,
+                39,
+                40,
+                41,
+                42,
             ],
             (new ParsingFileAnalyser(true, true))->ignoredLinesFor(
                 TEST_FILES_PATH . 'source_with_ignore.php'
@@ -136,4 +141,22 @@ final class ParsingFileAnalyserTest extends TestCase
         $this->assertSame(2, $result['commentLinesOfCode']);
         $this->assertSame(2, $result['nonCommentLinesOfCode']);
     }
+
+    /**
+     * @requires PHP 8
+     */
+    public function testLinesCanBeIgnoredUsingAttribute(): void
+    {
+        $this->assertSame(
+            [
+                4,
+                5,
+                12,
+                14,
+            ],
+            (new ParsingFileAnalyser(true, true))->ignoredLinesFor(
+                TEST_FILES_PATH . 'source_with_ignore_attributes.php'
+            )
+        );
+    }
 }
